/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.view.components
{
import flash.display.Sprite;
import flash.display.Graphics;

import mx.controls.DataGrid;
import mx.controls.listClasses.IListItemRenderer;
import mx.utils.ColorUtil;


public class RowColorDataGrid extends DataGrid
{

    public var rowColorFunction : Function;

    /**
     * Constructor. Calls the superclass constructor.
     */
    public function RowColorDataGrid()
    {
        super();
    }

    /**
     * Function that colors the backround of the row using the degree
     * of the notification. It uses a specific coloring function
     * called rowColorFunction.
     */
    override protected function drawRowBackground(s : Sprite, rowIndex : int, y : Number, height : Number, color : uint, dataIndex : int) : void
    {
        if (rowColorFunction != null && dataProvider != null)
        {
            var item : Object;

            if (dataIndex < dataProvider.length)
            {
                item = dataProvider[dataIndex];
            }

            if (item)
            {
                color = rowColorFunction(item, rowIndex, dataIndex, color);
            }

        }

        super.drawRowBackground(s, rowIndex, y, height, color, dataIndex);
    }

    /**
     * Function that draws a rectangle around the selected row
     */
	override protected function drawSelectionIndicator(indicator:Sprite, x:Number, y:Number, width:Number, height:Number, color:uint, itemRenderer:IListItemRenderer) : void
	{
		var g:Graphics = indicator.graphics;
		g.clear();
		g.beginFill(0x3f4c6b);
		g.lineStyle(3, 0x6e7c9d);
		g.drawRoundRect(x, y, unscaledWidth - viewMetrics.left - viewMetrics.right, height, 5, 5);
		g.endFill();
	}

    /**
     * Function that overrides the validateDisplayList. Together with that, it also modifies
     * the selection layer's alpha so that the selection color would be transparent.
     * This way, the original color is seen, while the row looks selected.
     */
    override public function validateDisplayList() : void
    {
        super.validateDisplayList();
        selectionLayer.alpha = .35;
    }

}

}
